==> qore-0.9.3.1.tar.bz2: qore-0.9.3.1/docs/modules/ConnectionProvider/html/search/all_f.js <==
var searchData=
[
  ['o_5faccmode',['O_ACCMODE',['../../../../lang/html/group__file__open__constants.html#ga8e48617453f7fd321bcceee8816bf23d',1,'Qore::O_ACCMODE()'],['../../../../lang/html/group__file__open__constants.html#ga8e48617453f7fd321bcceee8816bf23d',1,'O_ACCMODE()(Global Namespace)']]],
  ['o_5fappend',['O_APPEND',['../../../../lang/html/group__file__open__constants.html#gab47c6691139c37e08761a808d16ede1d',1,'Qore::O_APPEND()'],['../../../../lang/html/group__file__open__constants.html#gab47c6691139c37e08761a808d16ede1d',1,'O_APPEND()(Global Namespace)']]],
  ['o_5fcreat',['O_CREAT',['../../../../lang/html/group__file__open__constants.html#ga9af988b09d302ec0ae8605d5610e1e9a',1,'Qore::O_CREAT()'],['../../../../lang/html/group__file__open__constants.html#ga9af988b09d302ec0ae8605d5610e1e9a',1,'O_CREAT()(Global Namespace)']]],
  ['o_5fdirect',['O_DIRECT',['../../../../lang/html/group__file__open__constants.html#ga682b263ef12018bfd33ca8ba8bc8fd16',1,'Qore::O_DIRECT()'],['../../../../lang/html/group__file__open__constants.html#ga682b263ef12018bfd33ca8ba8bc8fd16',1,'O_DIRECT()(Global Namespace)']]],
  ['o_5fdirectory',['O_DIRECTORY',['../../../../lang/html/group__file__open__constants.html#ga5be496ec4bdff357baf0e742139c74b1',1,'Qore::O_DIRECTORY()'],['../../../../lang/html/group__file__open__constants.html#ga5be496ec4bdff357baf0e742139c74b1',1,'O_DIRECTORY()(Global Namespace)']]],
  ['o_5fexcl',['O_EXCL',['../../../../lang/html/group__file__open__constants.html#ga4ba47557022312d11d81f171fbb2e9ba',1,'Qore::O_EXCL()'],['../../../../lang/html/group__file__open__constants.html#ga4ba47557022312d11d81f171fbb2e9ba',1,'O_EXCL()(Global Namespace)']]],
  ['o_5fndelay',['O_NDELAY',['../../../../lang/html/group__file__open__constants.html#gaef24f5eb3bd3bd4dd9d4658577376715',1,'Qore::O_NDELAY()'],['../../../../lang/html/group__file__open__constants.html#gaef24f5eb3bd3bd4dd9d4658577376715',1,'O_NDELAY()(Global Namespace)']]],
  ['o_5fnoctty',['O_NOCTTY',['../../../../lang/html/group__file__open__constants.html#ga107ba322507fc52fe0c4a6537ded406a',1,'Qore::O_NOCTTY()'],['../../../../lang/html/group__file__open__constants.html#ga107ba322507fc52fe0c4a6537ded406a',1,'O_NOCTTY()(Global Namespace)']]],
  ['o_5fnofollow',['O_NOFOLLOW',['../../../../lang/html/group__file__open__constants.html#ga3452d00ede9696d75d1062d95da9449a',1,'Qore::O_NOFOLLOW()'],['../../../../lang/html/group__file__open__constants.html#ga3452d00ede9696d75d1062d95da9449a',1,'O_NOFOLLOW()(Global Namespace)']]],
  ['o_5fnonblock',['O_NONBLOCK',['../../../../lang/html/group__file__open__constants.html#gad5c43d9d32ea2b08ebbdfe70aa84710a',1,'Qore::O_NONBLOCK()'],['../../../../lang/html/group__file__open__constants.html#gad5c43d9d32ea2b08ebbdfe70aa84710a',1,'O_NONBLOCK()(Global Namespace)']]],
  ['o_5frdonly',['O_RDONLY',['../../../../lang/html/group__file__open__constants.html#ga1ab351549a0b39d1492dc0a48d199f64',1,'Qore::O_RDONLY()'],['../../../../lang/html/group__file__open__constants.html#ga1ab351549a0b39d1492dc0a48d199f64',1,'O_RDONLY()(Global Namespace)']]],
  ['o_5frdwr',['O_RDWR',['../../../../lang/html/group__file__open__constants.html#ga0d2a9837762a26e27fb666fa44358c37',1,'Qore::O_RDWR()'],['../../../../lang/html/group__file__open__constants.html#ga0d2a9837762a26e27fb666fa44358c37',1,'O_RDWR()(Global Namespace)']]],
  ['o_5fsync',['O_SYNC',['../../../../lang/html/group__file__open__constants.html#gacb2f3e1944dae38a5c4363ba21bbca11',1,'Qore::O_SYNC()'],['../../../../lang/html/group__file__open__constants.html#gacb2f3e1944dae38a5c4363ba21bbca11',1,'O_SYNC()(Global Namespace)']]],
  ['o_5ftrunc',['O_TRUNC',['../../../../lang/html/group__file__open__constants.html#gaeee59f4f7458e6d022dc84da0b9817af',1,'Qore::O_TRUNC()'],['../../../../lang/html/group__file__open__constants.html#gaeee59f4f7458e6d022dc84da0b9817af',1,'O_TRUNC()(Global Namespace)']]],
  ['o_5fwronly',['O_WRONLY',['../../../../lang/html/group__file__open__constants.html#ga24d94df00b8914ad6459e39cddfe15bf',1,'Qore::O_WRONLY()'],['../../../../lang/html/group__file__open__constants.html#ga24d94df00b8914ad6459e39cddfe15bf',1,'O_WRONLY()(Global Namespace)']]],
  ['object',['Object',['../../../../lang/html/group__string__type__constants.html#ga470369188279e07c29a3d1fc7b7a3c58',1,]]],
  ['object_20functions',['Object Functions',['../../../../lang/html/group__object__functions.html',1,'']]],
  ['objectiterator',['ObjectIterator',['../../../../lang/html/class_qore_1_1_object_iterator.html',1,'Qore']]],
  ['objectkeyiterator',['ObjectKeyIterator',['../../../../lang/html/class_qore_1_1_object_key_iterator.html',1,'Qore']]],
  ['objectkeyreverseiterator',['ObjectKeyReverseIterator',['../../../../lang/html/class_qore_1_1_object_key_reverse_iterator.html',1,'Qore']]],
  ['objectpairiterator',['ObjectPairIterator',['../../../../lang/html/class_qore_1_1_object_pair_iterator.html',1,'Qore']]],
  ['objectpairreverseiterator',['ObjectPairReverseIterator',['../../../../lang/html/class_qore_1_1_object_pair_reverse_iterator.html',1,'Qore']]],
  ['objectreverseiterator',['ObjectReverseIterator',['../../../../lang/html/class_qore_1_1_object_reverse_iterator.html',1,'Qore']]],
  ['objectserializationinfo',['ObjectSerializationInfo',['../../../../lang/html/struct_qore_1_1_object_serialization_info.html',1,'Qore']]],
  ['ocrnl',['OCRNL',['../../../../lang/html/group__tattr__output__mode__constants.html#gac81628928ae9b55ea854bfd9434f260c',1,'Qore::OCRNL()'],['../../../../lang/html/group__tattr__output__mode__constants.html#gac81628928ae9b55ea854bfd9434f260c',1,'OCRNL()(Global Namespace)']]],
  ['offset',['offset',['../../../../lang/html/struct_qore_1_1_call_stack_info.html#a75f754692ac785b55ec4b581c79c3239',1,'Qore::CallStackInfo::offset()'],['../../../../lang/html/struct_qore_1_1_exception_info.html#a3f928674aa77f0e2a4df65bbed28c80e',1,'Qore::ExceptionInfo::offset()'],['../../../../lang/html/struct_qore_1_1_source_location_info.html#aead6e94e470a3b59ed691f488b9233e0',1,'Qore::SourceLocationInfo::offset()'],['../../../../lang/html/struct_qore_1_1_statement_info.html#aae986844e41815e4a12d09a984050aa8',1,'Qore::StatementInfo::offset()']]],
  ['ok',['ok',['../struct_connection_provider_1_1_ping_info.html#a3097536dbb3a649f57b0c522d1ce8d1d',1,'ConnectionProvider::PingInfo']]],
  ['old_20dbi_20functions',['Old DBI Functions',['../../../../lang/html/group__old__dbi__functions.html',1,'']]],
  ['onattach',['onAttach',['../../../../lang/html/class_qore_1_1_debug_program.html#af6128c85bed20aa75ff620395d3e650e',1,'Qore::DebugProgram']]],
  ['ondetach',['onDetach',['../../../../lang/html/class_qore_1_1_debug_program.html#a9a4109f8e3f5571e45b1a398ffe3944a',1,'Qore::DebugProgram']]],
  ['onexception',['onException',['../../../../lang/html/class_qore_1_1_debug_program.html#a7875283d2d77e2f046f668ae1dbe1481',1,'Qore::DebugProgram']]],
  ['onexit',['onExit',['../../../../lang/html/class_qore_1_1_debug_program.html#aff4d8aa1dbc409efbe427cc497e6d6b9',1,'Qore::DebugProgram']]],
  ['onfunctionenter',['onFunctionEnter',['../../../../lang/html/class_qore_1_1_debug_program.html#a141bcffa9c0c190e1e7cfc0e6a7abc89',1,'Qore::DebugProgram']]],
  ['onfunctionexit',['onFunctionExit',['../../../../lang/html/class_qore_1_1_debug_program.html#a4312a29a6f9fc51f6a25a1c9441d2444',1,'Qore::DebugProgram']]],
  ['onlcr',['ONLCR',['../../../../lang/html/group__tattr__output__mode__constants.html#gaea2c1ed825b301f80a04d159701d5feb',1,'Qore::ONLCR()'],['../../../../lang/html/group__tattr__output__mode__constants.html#gaea2c1ed825b301f80a04d159701d5feb',1,'ONLCR()(Global Namespace)']]],
  ['onlret',['ONLRET',['../../../../lang/html/group__tattr__output__mode__constants.html#ga63e96508dd0b1895d55501580985b294',1,'Qore::ONLRET()'],['../../../../lang/html/group__tattr__output__mode__constants.html#ga63e96508dd0b1895d55501580985b294',1,'ONLRET()(Global Namespace)']]],
  ['onocr',['ONOCR',['../../../../lang/html/group__tattr__output__mode__constants.html#ga00759299e93bb514684789a1977f71f4',1,'Qore::ONOCR()'],['../../../../lang/html/group__tattr__output__mode__constants.html#ga00759299e93bb514684789a1977f71f4',1,'ONOCR()(Global Namespace)']]],
  ['onoeot',['ONOEOT',['../../../../lang/html/group__tattr__output__mode__constants.html#ga1c5645b75037e57d41b0ba8452e8af63',1,'Qore::ONOEOT()'],['../../../../lang/html/group__tattr__output__mode__constants.html#ga1c5645b75037e57d41b0ba8452e8af63',1,'ONOEOT()(Global Namespace)']]],
  ['onstep',['onStep',['../../../../lang/html/class_qore_1_1_debug_program.html#ad8cd7b6c9842b2f05888713d1deaf9c7',1,'Qore::DebugProgram']]],
  ['open',['open',['../../../../lang/html/class_qore_1_1_s_q_l_1_1_datasource.html#aa6a07369dd7563f1db552588f41e02e7',1,'Qore::SQL::Datasource::open()'],['../../../../lang/html/class_qore_1_1_file.html#a0f0e402ebce26412fa854b3647a13c15',1,'Qore::File::open()'],['../../../../lang/html/class_qore_1_1_read_only_file.html#a487b2f0b5b97ac8958eff649867f97ff',1,'Qore::ReadOnlyFile::open()']]],
  ['open2',['open2',['../../../../lang/html/class_qore_1_1_file.html#acb397de36027a83129823742ac97c157',1,'Qore::File']]],
  ['opendir',['openDir',['../../../../lang/html/class_qore_1_1_dir.html#a3f85f9096e3fcc143e738982e5594ac2',1,'Qore::Dir']]],
  ['openfile',['openFile',['../../../../lang/html/class_qore_1_1_dir.html#a11575c0b4bc1d08c423af79b3be908d6',1,'Qore::Dir']]],
  ['operators',['Operators',['../../../../lang/html/operators.html',1,'']]],
  ['opost',['OPOST',['../../../../lang/html/group__tattr__output__mode__constants.html#ga1bff47227b0accb43061f7b7b57dd4fe',1,'Qore::OPOST()'],['../../../../lang/html/group__tattr__output__mode__constants.html#ga1bff47227b0accb43061f7b7b57dd4fe',1,'OPOST()(Global Namespace)']]],
  ['option_20constants',['Option Constants',['../../../../lang/html/group__option__constants.html',1,'']]],
  ['optionlist',['OptionList',['../class_connection_provider_1_1_filesystem_connection.html#a583bc2d6ddd20245728aaed73046cfb2',1,'ConnectionProvider::FilesystemConnection']]],
  ['options',['Options',['../class_connection_provider_1_1_filesystem_connection.html#ab852811cc21179678ac30ea78eec25f3',1,'ConnectionProvider::FilesystemConnection::Options()'],['../class_connection_provider_1_1_http_connection.html#a7d2c0780ee703aa1e08e472b0dfa5c80',1,'ConnectionProvider::HttpConnection::Options()']]],
  ['opts',['opts',['../class_connection_provider_1_1_abstract_connection.html#a5c3ae344e85bb6c4301555574f38d863',1,'ConnectionProvider::AbstractConnection::opts()'],['../struct_connection_provider_1_1_connection_info.html#a633e4ae13939ec27d9a7afbb30652619',1,'ConnectionProvider::ConnectionInfo::opts()'],['../struct_connection_provider_1_1_config_info.html#a13bc5c0d0ebfad791c65cc093d625e89',1,'ConnectionProvider::ConfigInfo::opts()'],['../struct_connection_provider_1_1_ping_info.html#a56ed1d6d38f6620c8c6bfb1977007a63',1,'ConnectionProvider::PingInfo::opts()']]],
  ['ord',['ord',['../../../../lang/html/group__string__functions.html#gab1aedfc4b3b7aed6dffead7e46c72b07',1,'Qore::ord(softstring str, softint offset=0)'],['../../../../lang/html/group__string__functions.html#gab998e345a65c1e98ca9370c3a324f9cb',1,'Qore::ord()'],['../../../../lang/html/group__string__functions.html#gab1aedfc4b3b7aed6dffead7e46c72b07',1,'ord(softstring str, softint offset=0)(Global Namespace)'],['../../../../lang/html/group__string__functions.html#gab998e345a65c1e98ca9370c3a324f9cb',1,'ord()(Global Namespace)']]],
  ['orig_5fopts',['orig_opts',['../class_connection_provider_1_1_abstract_connection.html#a6ffc1ba138bd2607a50f37bad3e6352b',1,'ConnectionProvider::AbstractConnection']]],
  ['outputstream',['OutputStream',['../../../../lang/html/class_qore_1_1_output_stream.html',1,'Qore']]],
  ['overloading',['Overloading',['../../../../lang/html/overloading.html',1,'']]],
  ['oxtabs',['OXTABS',['../../../../lang/html/group__tattr__output__mode__constants.html#ga527998ca23a5263066670d3a3109ed67',1,'Qore::OXTABS()'],['../../../../lang/html/group__tattr__output__mode__constants.html#ga527998ca23a5263066670d3a3109ed67',1,'OXTABS()(Global Namespace)']]]
];

==> qore-0.9.4.tar.bz2: qore-0.9.4/docs/modules/ConnectionProvider/html/search/all_f.js <==
var searchData=
[
  ['o_5faccmode',['O_ACCMODE',['../../../../lang/html/group__file__open__constants.html#ga8e48617453f7fd321bcceee8816bf23d',1,'Qore::O_ACCMODE()'],['../../../../lang/html/group__file__open__constants.html#ga8e48617453f7fd321bcceee8816bf23d',1,'O_ACCMODE()(Global Namespace)']]],
  ['o_5fappend',['O_APPEND',['../../../../lang/html/group__file__open__constants.html#gab47c6691139c37e08761a808d16ede1d',1,'Qore::O_APPEND()'],['../../../../lang/html/group__file__open__constants.html#gab47c6691139c37e08761a808d16ede1d',1,'O_APPEND()(Global Namespace)']]],
  ['o_5fcreat',['O_CREAT',['../../../../lang/html/group__file__open__constants.html#ga9af988b09d302ec0ae8605d5610e1e9a',1,'Qore::O_CREAT()'],['../../../../lang/html/group__file__open__constants.html#ga9af988b09d302ec0ae8605d5610e1e9a',1,'O_CREAT()(Global Namespace)']]],
  ['o_5fdirect',['O_DIRECT',['../../../../lang/html/group__file__open__constants.html#ga682b263ef12018bfd33ca8ba8bc8fd16',1,'Qore::O_DIRECT()'],['../../../../lang/html/group__file__open__constants.html#ga682b263ef12018bfd33ca8ba8bc8fd16',1,'O_DIRECT()(Global Namespace)']]],
  ['o_5fdirectory',['O_DIRECTORY',['../../../../lang/html/group__file__open__constants.html#ga5be496ec4bdff357baf0e742139c74b1',1,'Qore::O_DIRECTORY()'],['../../../../lang/html/group__file__open__constants.html#ga5be496ec4bdff357baf0e742139c74b1',1,'O_DIRECTORY()(Global Namespace)']]],
  ['o_5fexcl',['O_EXCL',['../../../../lang/html/group__file__open__constants.html#ga4ba47557022312d11d81f171fbb2e9ba',1,'Qore::O_EXCL()'],['../../../../lang/html/group__file__open__constants.html#ga4ba47557022312d11d81f171fbb2e9ba',1,'O_EXCL()(Global Namespace)']]],
  ['o_5fndelay',['O_NDELAY',['../../../../lang/html/group__file__open__constants.html#gaef24f5eb3bd3bd4dd9d4658577376715',1,'Qore::O_NDELAY()'],['../../../../lang/html/group__file__open__constants.html#gaef24f5eb3bd3bd4dd9d4658577376715',1,'O_NDELAY()(Global Namespace)']]],
  ['o_5fnoctty',['O_NOCTTY',['../../../../lang/html/group__file__open__constants.html#ga107ba322507fc52fe0c4a6537ded406a',1,'Qore::O_NOCTTY()'],['../../../../lang/html/group__file__open__constants.html#ga107ba322507fc52fe0c4a6537ded406a',1,'O_NOCTTY()(Global Namespace)']]],
  ['o_5fnofollow',['O_NOFOLLOW',['../../../../lang/html/group__file__open__constants.html#ga3452d00ede9696d75d1062d95da9449a',1,'Qore::O_NOFOLLOW()'],['../../../../lang/html/group__file__open__constants.html#ga3452d00ede9696d75d1062d95da9449a',1,'O_NOFOLLOW()(Global Namespace)']]],
  ['o_5fnonblock',['O_NONBLOCK',['../../../../lang/html/group__file__open__constants.html#gad5c43d9d32ea2b08ebbdfe70aa84710a',1,'Qore::O_NONBLOCK()'],['../../../../lang/html/group__file__open__constants.html#gad5c43d9d32ea2b08ebbdfe70aa84710a',1,'O_NONBLOCK()(Global Namespace)']]],
  ['o_5frdonly',['O_RDONLY',['../../../../lang/html/group__file__open__constants.html#ga1ab351549a0b39d1492dc0a48d199f64',1,'Qore::O_RDONLY()'],['../../../../lang/html/group__file__open__constants.html#ga1ab351549a0b39d1492dc0a48d199f64',1,'O_RDONLY()(Global Namespace)']]],
  ['o_5frdwr',['O_RDWR',['../../../../lang/html/group__file__open__constants.html#ga0d2a9837762a26e27fb666fa44358c37',1,'Qore::O_RDWR()'],['../../../../lang/html/group__file__open__constants.html#ga0d2a9837762a26e27fb666fa44358c37',1,'O_RDWR()(Global Namespace)']]],
  ['o_5fsync',['O_SYNC',['../../../../lang/html/group__file__open__constants.html#gacb2f3e1944dae38a5c4363ba21bbca11',1,'Qore::O_SYNC()'],['../../../../lang/html/group__file__open__constants.html#gacb2f3e1944dae38a5c4363ba21bbca11',1,'O_SYNC()(Global Namespace)']]],
  ['o_5ftrunc',['O_TRUNC',['../../../../lang/html/group__file__open__constants.html#gaeee59f4f7458e6d022dc84da0b9817af',1,'Qore::O_TRUNC()'],['../../../../lang/html/group__file__open__constants.html#gaeee59f4f7458e6d022dc84da0b9817af',1,'O_TRUNC()(Global Namespace)']]],
  ['o_5fwronly',['O_WRONLY',['../../../../lang/html/group__file__open__constants.html#ga24d94df00b8914ad6459e39cddfe15bf',1,'Qore::O_WRONLY()'],['../../../../lang/html/group__file__open__constants.html#ga24d94df00b8914ad6459e39cddfe15bf',1,'O_WRONLY()(Global Namespace)']]],
  ['object',['Object',['../../../../lang/html/group__string__type__constants.html#ga470369188279e07c29a3d1fc7b7a3c58',1,'Qore::Type::Object()'],['../../../../lang/html/group__string__type__constants.html#ga470369188279e07c29a3d1fc7b7a3c58',1,'Object()(Global Namespace)']]],
  ['object_20functions',['Object Functions',['../../../../lang/html/group__object__functions.html',1,'']]],
  ['objectiterator',['ObjectIterator',['../../../../lang/html/class_qore_1_1_object_iterator.html',1,'Qore']]],
  ['objectkeyiterator',['ObjectKeyIterator',['../../../../lang/html/class_qore_1_1_object_key_iterator.html',1,'Qore']]],
  ['objectkeyreverseiterator',['ObjectKeyReverseIterator',['../../../../lang/html/class_qore_1_1_object_key_reverse_iterator.html',1,'Qore']]],
  ['objectpairiterator',['ObjectPairIterator',['../../../../lang/html/class_qore_1_1_object_pair_iterator.html',1,'Qore']]],
  ['objectpairreverseiterator',['ObjectPairReverseIterator',['../../../../lang/html/class_qore_1_1_object_pair_reverse_iterator.html',1,'Qore']]],
  ['objectreverseiterator',['ObjectReverseIterator',['../../../../lang/html/class_qore_1_1_object_reverse_iterator.html',1,'Qore']]],
  ['objectserializationinfo',['ObjectSerializationInfo',['../../../../lang/html/struct_qore_1_1_object_serialization_info.html',1,'Qore']]],
  ['ocrnl',['OCRNL',['../../../../lang/html/group__tattr__output__mode__constants.html#gac81628928ae9b55ea854bfd9434f260c',1,'Qore::OCRNL()'],['../../../../lang/html/group__tattr__output__mode__constants.html#gac81628928ae9b55ea854bfd9434f260c',1,'OCRNL()(Global Namespace)']]],
  ['offset',['offset',['../../../../lang/html/struct_qore_1_1_call_stack_info.html#a75f754692ac785b55ec4b581c79c3239',1,'Qore::CallStackInfo::offset()'],['../../../../lang/html/struct_qore_1_1_exception_info.html#a3f928674aa77f0e2a4df65bbed28c80e',1,'Qore::ExceptionInfo::offset()'],['../../../../lang/html/struct_qore_1_1_source_location_info.html#aead6e94e470a3b59ed691f488b9233e0',1,'Qore::SourceLocationInfo::offset()'],['../../../../lang/html/struct_qore_1_1_statement_info.html#aae986844e41815e4a12d09a984050aa8',1,'Qore::StatementInfo::offset()']]],
  ['ok',['ok',['../struct_connection_provider_1_1_ping_info.html#a3097536dbb3a649f57b0c522d1ce8d1d',1,'ConnectionProvider::PingInfo']]],
  ['old_20dbi_20functions',['Old DBI Functions',['../../../../lang/html/group__old__dbi__functions.html',1,'']]],
  ['onattach',['onAttach',['../../../../lang/html/class_qore_1_1_debug_program.html#af6128c85bed20aa75ff620395d3e650e',1,'Qore::DebugProgram']]],
  ['ondetach',['onDetach',['../../../../lang/html/class_qore_1_1_debug_program.html#a9a4109f8e3f5571e45b1a398ffe3944a',1,'Qore::DebugProgram']]],
  ['onexception',['onException',['../../../../lang/html/class_qore_1_1_debug_program.html#a7875283d2d77e2f046f668ae1dbe1481',1,'Qore::DebugProgram']]],
  ['onexit',['onExit',['../../../../lang/html/class_qore_1_1_debug_program.html#aff4d8aa1dbc409efbe427cc497e6d6b9',1,'Qore::DebugProgram']]],
  ['onfunctionenter',['onFunctionEnter',['../../../../lang/html/class_qore_1_1_debug_program.html#a141bcffa9c0c190e1e7cfc0e6a7abc89',1,'Qore::DebugProgram']]],
  ['onfunctionexit',['onFunctionExit',['../../../../lang/html/class_qore_1_1_debug_program.html#a4312a29a6f9fc51f6a25a1c9441d2444',1,'Qore::DebugProgram']]],
  ['onlcr',['ONLCR',['../../../../lang/html/group__tattr__output__mode__constants.html#gaea2c1ed825b301f80a04d159701d5feb',1,'Qore::ONLCR()'],['../../../../lang/html/group__tattr__output__mode__constants.html#gaea2c1ed825b301f80a04d159701d5feb',1,'ONLCR()(Global Namespace)']]],
  ['onlret',['ONLRET',['../../../../lang/html/group__tattr__output__mode__constants.html#ga63e96508dd0b1895d55501580985b294',1,'Qore::ONLRET()'],['../../../../lang/html/group__tattr__output__mode__constants.html#ga63e96508dd0b1895d55501580985b294',1,'ONLRET()(Global Namespace)']]],
  ['onocr',['ONOCR',['../../../../lang/html/group__tattr__output__mode__constants.html#ga00759299e93bb514684789a1977f71f4',1,'Qore::ONOCR()'],['../../../../lang/html/group__tattr__output__mode__constants.html#ga00759299e93bb514684789a1977f71f4',1,'ONOCR()(Global Namespace)']]],
  ['onoeot',['ONOEOT',['../../../../lang/html/group__tattr__output__mode__constants.html#ga1c5645b75037e57d41b0ba8452e8af63',1,'Qore::ONOEOT()'],['../../../../lang/html/group__tattr__output__mode__constants.html#ga1c5645b75037e57d41b0ba8452e8af63',1,'ONOEOT()(Global Namespace)']]],
  ['onstep',['onStep',['../../../../lang/html/class_qore_1_1_debug_program.html#ad8cd7b6c9842b2f05888713d1deaf9c7',1,'Qore::DebugProgram']]],
  ['open',['open',['../../../../lang/html/class_qore_1_1_s_q_l_1_1_datasource.html#aa6a07369dd7563f1db552588f41e02e7',1,'Qore::SQL::Datasource::open()'],['../../../../lang/html/class_qore_1_1_file.html#a0f0e402ebce26412fa854b3647a13c15',1,'Qore::File::open()'],['../../../../lang/html/class_qore_1_1_read_only_file.html#a487b2f0b5b97ac8958eff649867f97ff',1,'Qore::ReadOnlyFile::open()']]],
  ['open2',['open2',['../../../../lang/html/class_qore_1_1_file.html#acb397de36027a83129823742ac97c157',1,'Qore::File']]],
  ['opendir',['openDir',['../../../../lang/html/class_qore_1_1_dir.html#a3f85f9096e3fcc143e738982e5594ac2',1,'Qore::Dir']]],
  ['openfile',['openFile',['../../../../lang/html/class_qore_1_1_dir.html#a11575c0b4bc1d08c423af79b3be908d6',1,'Qore::Dir']]],
  ['operators',['Operators',['../../../../lang/html/operators.html',1,'']]],
  ['opost',['OPOST',['../../../../lang/html/group__tattr__output__mode__constants.html#ga1bff47227b0accb43061f7b7b57dd4fe',1,'Qore::OPOST()'],['../../../../lang/html/group__tattr__output__mode__constants.html#ga1bff47227b0accb43061f7b7b57dd4fe',1,'OPOST()(Global Namespace)']]],
  ['option_20constants',['Option Constants',['../../../../lang/html/group__option__constants.html',1,'']]],
  ['optionlist',['OptionList',['../class_connection_provider_1_1_filesystem_connection.html#a583bc2d6ddd20245728aaed73046cfb2',1,'ConnectionProvider::FilesystemConnection']]],
  ['options',['Options',['../class_connection_provider_1_1_filesystem_connection.html#ab852811cc21179678ac30ea78eec25f3',1,'ConnectionProvider::FilesystemConnection::Options()'],['../class_connection_provider_1_1_http_connection.html#a7d2c0780ee703aa1e08e472b0dfa5c80',1,'ConnectionProvider::HttpConnection::Options()']]],
  ['opts',['opts',['../class_connection_provider_1_1_abstract_connection.html#a133a28b83a8baa994130bfa5e47fc235',1,'ConnectionProvider::AbstractConnection::opts()'],['../struct_connection_provider_1_1_connection_info.html#a633e4ae13939ec27d9a7afbb30652619',1,'ConnectionProvider::ConnectionInfo::opts()'],['../struct_connection_provider_1_1_config_info.html#a13bc5c0d0ebfad791c65cc093d625e89',1,'ConnectionProvider::ConfigInfo::opts()'],['../struct_connection_provider_1_1_ping_info.html#a56ed1d6d38f6620c8c6bfb1977007a63',1,'ConnectionProvider::PingInfo::opts()']]],
  ['ord',['ord',['../../../../lang/html/group__string__functions.html#gab1aedfc4b3b7aed6dffead7e46c72b07',1,'Qore::ord(softstring str, softint offset=0)'],['../../../../lang/html/group__string__functions.html#gab998e345a65c1e98ca9370c3a324f9cb',1,'Qore::ord()'],['../../../../lang/html/group__string__functions.html#gab1aedfc4b3b7aed6dffead7e46c72b07',1,'ord(softstring str, softint offset=0)(Global Namespace)'],['../../../../lang/html/group__string__functions.html#gab998e345a65c1e98ca9370c3a324f9cb',1,'ord()(Global Namespace)']]],
  ['orig_5fopts',['orig_opts',['../class_connection_provider_1_1_abstract_connection.html#a2fb6cfafb19d7f777cd9cbb58ab439ec',1,'ConnectionProvider::AbstractConnection']]],
  ['outputstream',['OutputStream',['../../../../lang/html/class_qore_1_1_output_stream.html',1,'Qore']]],
  ['overloading',['Overloading',['../../../../lang/html/overloading.html',1,'']]],
  ['oxtabs',['OXTABS',['../../../../lang/html/group__tattr__output__mode__constants.html#ga527998ca23a5263066670d3a3109ed67',1,'Qore::OXTABS()'],['../../../../lang/html/group__tattr__output__mode__constants.html#ga527998ca23a5263066670d3a3109ed67',1,'OXTABS()(Global Namespace)']]]
];
